@@ -27,7 +27,7 @@ class UrllibWrapper ():
         
     def get_url (self, url):
         request = urllib2.Request (url)
-        request.add_header ('User-Agent', 'Mussorgsky/0.1 Test')
+        request.add_header ('User-Agent', 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.1; WOW64; Trident/6.0)')
         opener = urllib2.build_opener ()
         try:
             return opener.open (request).read ()
